# Typeracer scraper

This is a simple example package. You can use
[Github-flavored Markdown](https://github.com/Mohammad-Kheir/TypeRacerScraper)
given a user id and a number of scores it will return list of scores.
